Class: Google::Apis::CloudassetV1p1beta1::GoogleIdentityAccesscontextmanagerV1BasicLevel

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1p1beta1/classes.rb,
lib/google/apis/cloudasset_v1p1beta1/representations.rb,
lib/google/apis/cloudasset_v1p1beta1/representations.rb

Overview

BasicLevel is an AccessLevel using a set of recommended features.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1BasicLevel

Returns a new instance of GoogleIdentityAccesscontextmanagerV1BasicLevel.



1091
1092
1093
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 1091

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#combining_functionString

How the conditions list should be combined to determine if a request is granted this AccessLevel. If AND is used, each Condition in conditions must be satisfied for the AccessLevel to be applied. If OR is used, at least one Condition in conditions must be satisfied for the AccessLevel to be applied. Default behavior is AND. Corresponds to the JSON property combiningFunction

Returns:

  • (String)


1084
1085
1086
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 1084

def combining_function
  @combining_function
end

#conditionsArray<Google::Apis::CloudassetV1p1beta1::GoogleIdentityAccesscontextmanagerV1Condition>

Required. A list of requirements for the AccessLevel to be granted. Corresponds to the JSON property conditions



1089
1090
1091
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 1089

def conditions
  @conditions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1096
1097
1098
1099
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 1096

def update!(**args)
  @combining_function = args[:combining_function] if args.key?(:combining_function)
  @conditions = args[:conditions] if args.key?(:conditions)
end