Class: Google::Apis::CloudassetV1p1beta1::GoogleIdentityAccesscontextmanagerV1EgressFrom

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1p1beta1/classes.rb,
lib/google/apis/cloudasset_v1p1beta1/representations.rb,
lib/google/apis/cloudasset_v1p1beta1/representations.rb

Overview

Defines the conditions under which an EgressPolicy matches a request. Conditions based on information about the source of the request. Note that if the destination of the request is also protected by a ServicePerimeter, then that ServicePerimeter must have an IngressPolicy which allows access in order for this request to succeed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1EgressFrom

Returns a new instance of GoogleIdentityAccesscontextmanagerV1EgressFrom.



1316
1317
1318
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 1316

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#identitiesArray<String>

A list of identities that are allowed access through [EgressPolicy]. Identities can be an individual user, service account, Google group, third- party identity, or agent identity. For the list of supported identity types, see https://docs.cloud.google.com/vpc-service-controls/docs/supported- identities. Corresponds to the JSON property identities

Returns:

  • (Array<String>)


1294
1295
1296
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 1294

def identities
  @identities
end

#identity_typeString

Specifies the type of identities that are allowed access to outside the perimeter. If left unspecified, then members of identities field will be allowed access. Corresponds to the JSON property identityType

Returns:

  • (String)


1301
1302
1303
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 1301

def identity_type
  @identity_type
end

#source_restrictionString

Whether to enforce traffic restrictions based on sources field. If the sources fields is non-empty, then this field must be set to SOURCE_RESTRICTION_ENABLED. Corresponds to the JSON property sourceRestriction

Returns:

  • (String)


1308
1309
1310
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 1308

def source_restriction
  @source_restriction
end

#sourcesArray<Google::Apis::CloudassetV1p1beta1::GoogleIdentityAccesscontextmanagerV1EgressSource>

Sources that this EgressPolicy authorizes access from. If this field is not empty, then source_restriction must be set to SOURCE_RESTRICTION_ENABLED. Corresponds to the JSON property sources



1314
1315
1316
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 1314

def sources
  @sources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1321
1322
1323
1324
1325
1326
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 1321

def update!(**args)
  @identities = args[:identities] if args.key?(:identities)
  @identity_type = args[:identity_type] if args.key?(:identity_type)
  @source_restriction = args[:source_restriction] if args.key?(:source_restriction)
  @sources = args[:sources] if args.key?(:sources)
end