Class: Google::Apis::CloudassetV1p1beta1::GoogleIdentityAccesscontextmanagerV1EgressSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1p1beta1/classes.rb,
lib/google/apis/cloudasset_v1p1beta1/representations.rb,
lib/google/apis/cloudasset_v1p1beta1/representations.rb

Overview

The source that EgressPolicy authorizes access from inside the ServicePerimeter to somewhere outside the ServicePerimeter boundaries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1EgressSource

Returns a new instance of GoogleIdentityAccesscontextmanagerV1EgressSource.



1414
1415
1416
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 1414

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_levelString

An AccessLevel resource name that allows protected resources inside the ServicePerimeters to access outside the ServicePerimeter boundaries. AccessLevels listed must be in the same policy as this ServicePerimeter. Referencing a nonexistent AccessLevel will cause an error. If an AccessLevel name is not specified, only resources within the perimeter can be accessed through Google Cloud calls with request origins within the perimeter. Example: accessPolicies/MY_POLICY/accessLevels/MY_LEVEL. If a single * is specified for access_level, then all EgressSources will be allowed. Corresponds to the JSON property accessLevel

Returns:

  • (String)


1399
1400
1401
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 1399

def access_level
  @access_level
end

#psc_endpointGoogle::Apis::CloudassetV1p1beta1::GoogleIdentityAccesscontextmanagerV1PrivateServiceConnectEndpoint

Specifies the PSC an API call refers to. Corresponds to the JSON property pscEndpoint



1404
1405
1406
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 1404

def psc_endpoint
  @psc_endpoint
end

#resourceString

A Google Cloud resource from the service perimeter that you want to allow to access data outside the perimeter. This field supports only projects. The project format is projects/project_number`. You can't use*in this field to allow all Google Cloud resources. Corresponds to the JSON propertyresource`

Returns:

  • (String)


1412
1413
1414
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 1412

def resource
  @resource
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1419
1420
1421
1422
1423
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 1419

def update!(**args)
  @access_level = args[:access_level] if args.key?(:access_level)
  @psc_endpoint = args[:psc_endpoint] if args.key?(:psc_endpoint)
  @resource = args[:resource] if args.key?(:resource)
end