Class: Google::Apis::CloudassetV1p1beta1::SearchAllIamPoliciesResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1p1beta1::SearchAllIamPoliciesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1p1beta1/classes.rb,
lib/google/apis/cloudasset_v1p1beta1/representations.rb,
lib/google/apis/cloudasset_v1p1beta1/representations.rb
Overview
Search all IAM policies response.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Set if there are more results than those appearing in this response; to get the next set of results, call this method again, using this value as the
page_token. -
#results ⇒ Array<Google::Apis::CloudassetV1p1beta1::IamPolicySearchResult>
A list of IAM policies that match the search query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchAllIamPoliciesResponse
constructor
A new instance of SearchAllIamPoliciesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchAllIamPoliciesResponse
Returns a new instance of SearchAllIamPoliciesResponse.
2242 2243 2244 |
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2242 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Set if there are more results than those appearing in this response; to get
the next set of results, call this method again, using this value as the
page_token.
Corresponds to the JSON property nextPageToken
2234 2235 2236 |
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2234 def next_page_token @next_page_token end |
#results ⇒ Array<Google::Apis::CloudassetV1p1beta1::IamPolicySearchResult>
A list of IAM policies that match the search query. Related information such
as the associated resource is returned along with the policy.
Corresponds to the JSON property results
2240 2241 2242 |
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2240 def results @results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2247 2248 2249 2250 |
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2247 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @results = args[:results] if args.key?(:results) end |