Class: Google::Apis::CloudassetV1p1beta1::StandardResourceMetadata
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1p1beta1::StandardResourceMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1p1beta1/classes.rb,
lib/google/apis/cloudasset_v1p1beta1/representations.rb,
lib/google/apis/cloudasset_v1p1beta1/representations.rb
Overview
The standard metadata of a cloud resource.
Instance Attribute Summary collapse
-
#additional_attributes ⇒ Array<String>
Additional searchable attributes of this resource.
-
#asset_type ⇒ String
The type of this resource.
-
#description ⇒ String
One or more paragraphs of text description of this resource.
-
#display_name ⇒ String
The display name of this resource.
-
#labels ⇒ Hash<String,String>
Labels associated with this resource.
-
#location ⇒ String
Location can be "global", regional like "us-east1", or zonal like "us-west1-b".
-
#name ⇒ String
The full resource name.
-
#network_tags ⇒ Array<String>
Network tags associated with this resource.
-
#project ⇒ String
The project that this resource belongs to, in the form of
projects/project_number``.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StandardResourceMetadata
constructor
A new instance of StandardResourceMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StandardResourceMetadata
Returns a new instance of StandardResourceMetadata.
2341 2342 2343 |
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2341 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_attributes ⇒ Array<String>
Additional searchable attributes of this resource. Informational only. The
exact set of attributes is subject to change. For example: project id, DNS
name etc.
Corresponds to the JSON property additionalAttributes
2289 2290 2291 |
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2289 def additional_attributes @additional_attributes end |
#asset_type ⇒ String
The type of this resource. For example: "compute.googleapis.com/Disk".
Corresponds to the JSON property assetType
2294 2295 2296 |
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2294 def asset_type @asset_type end |
#description ⇒ String
One or more paragraphs of text description of this resource. Maximum length
could be up to 1M bytes.
Corresponds to the JSON property description
2300 2301 2302 |
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2300 def description @description end |
#display_name ⇒ String
The display name of this resource.
Corresponds to the JSON property displayName
2305 2306 2307 |
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2305 def display_name @display_name end |
#labels ⇒ Hash<String,String>
Labels associated with this resource. See Labelling and grouping Google Cloud
resources for more information.
Corresponds to the JSON property labels
2312 2313 2314 |
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2312 def labels @labels end |
#location ⇒ String
Location can be "global", regional like "us-east1", or zonal like "us-west1-b".
Corresponds to the JSON property location
2317 2318 2319 |
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2317 def location @location end |
#name ⇒ String
The full resource name. For example: //compute.googleapis.com/projects/
my_project_123/zones/zone1/instances/instance1. See Resource Names for more
information.
Corresponds to the JSON property name
2325 2326 2327 |
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2325 def name @name end |
#network_tags ⇒ Array<String>
Network tags associated with this resource. Like labels, network tags are a
type of annotations used to group Google Cloud resources. See Labelling
Google Cloud resources for more information.
Corresponds to the JSON property networkTags
2333 2334 2335 |
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2333 def @network_tags end |
#project ⇒ String
The project that this resource belongs to, in the form of projects/
project_number`.
Corresponds to the JSON propertyproject`
2339 2340 2341 |
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2339 def project @project end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 |
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2346 def update!(**args) @additional_attributes = args[:additional_attributes] if args.key?(:additional_attributes) @asset_type = args[:asset_type] if args.key?(:asset_type) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @network_tags = args[:network_tags] if args.key?(:network_tags) @project = args[:project] if args.key?(:project) end |