Class: Google::Apis::CloudassetV1p1beta1::GoogleIdentityAccesscontextmanagerV1IngressFrom
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1p1beta1::GoogleIdentityAccesscontextmanagerV1IngressFrom
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1p1beta1/classes.rb,
lib/google/apis/cloudasset_v1p1beta1/representations.rb,
lib/google/apis/cloudasset_v1p1beta1/representations.rb
Overview
Defines the conditions under which an IngressPolicy matches a request.
Conditions are based on information about the source of the request. The
request must satisfy what is defined in sources AND identity related fields
in order to match.
Instance Attribute Summary collapse
-
#identities ⇒ Array<String>
A list of identities that are allowed access through [IngressPolicy].
-
#identity_type ⇒ String
Specifies the type of identities that are allowed access from outside the perimeter.
-
#sources ⇒ Array<Google::Apis::CloudassetV1p1beta1::GoogleIdentityAccesscontextmanagerV1IngressSource>
Sources that this IngressPolicy authorizes access from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1IngressFrom
constructor
A new instance of GoogleIdentityAccesscontextmanagerV1IngressFrom.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1IngressFrom
Returns a new instance of GoogleIdentityAccesscontextmanagerV1IngressFrom.
1509 1510 1511 |
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 1509 def initialize(**args) update!(**args) end |
Instance Attribute Details
#identities ⇒ Array<String>
A list of identities that are allowed access through [IngressPolicy].
Identities can be an individual user, service account, Google group, third-
party identity, or agent identity. For the list of supported identity types,
see https://docs.cloud.google.com/vpc-service-controls/docs/supported-
identities.
Corresponds to the JSON property identities
1495 1496 1497 |
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 1495 def identities @identities end |
#identity_type ⇒ String
Specifies the type of identities that are allowed access from outside the
perimeter. If left unspecified, then members of identities field will be
allowed access.
Corresponds to the JSON property identityType
1502 1503 1504 |
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 1502 def identity_type @identity_type end |
#sources ⇒ Array<Google::Apis::CloudassetV1p1beta1::GoogleIdentityAccesscontextmanagerV1IngressSource>
Sources that this IngressPolicy authorizes access from.
Corresponds to the JSON property sources
1507 1508 1509 |
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 1507 def sources @sources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1514 1515 1516 1517 1518 |
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 1514 def update!(**args) @identities = args[:identities] if args.key?(:identities) @identity_type = args[:identity_type] if args.key?(:identity_type) @sources = args[:sources] if args.key?(:sources) end |