Class: Google::Apis::CloudassetV1p1beta1::StandardResourceMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1p1beta1/classes.rb,
lib/google/apis/cloudasset_v1p1beta1/representations.rb,
lib/google/apis/cloudasset_v1p1beta1/representations.rb

Overview

The standard metadata of a cloud resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StandardResourceMetadata

Returns a new instance of StandardResourceMetadata.



2218
2219
2220
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2218

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_attributesArray<String>

Additional searchable attributes of this resource. Informational only. The exact set of attributes is subject to change. For example: project id, DNS name etc. Corresponds to the JSON property additionalAttributes

Returns:

  • (Array<String>)


2166
2167
2168
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2166

def additional_attributes
  @additional_attributes
end

#asset_typeString

The type of this resource. For example: "compute.googleapis.com/Disk". Corresponds to the JSON property assetType

Returns:

  • (String)


2171
2172
2173
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2171

def asset_type
  @asset_type
end

#descriptionString

One or more paragraphs of text description of this resource. Maximum length could be up to 1M bytes. Corresponds to the JSON property description

Returns:

  • (String)


2177
2178
2179
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2177

def description
  @description
end

#display_nameString

The display name of this resource. Corresponds to the JSON property displayName

Returns:

  • (String)


2182
2183
2184
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2182

def display_name
  @display_name
end

#labelsHash<String,String>

Labels associated with this resource. See Labelling and grouping Google Cloud resources for more information. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2189
2190
2191
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2189

def labels
  @labels
end

#locationString

Location can be "global", regional like "us-east1", or zonal like "us-west1-b". Corresponds to the JSON property location

Returns:

  • (String)


2194
2195
2196
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2194

def location
  @location
end

#nameString

The full resource name. For example: //compute.googleapis.com/projects/ my_project_123/zones/zone1/instances/instance1. See Resource Names for more information. Corresponds to the JSON property name

Returns:

  • (String)


2202
2203
2204
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2202

def name
  @name
end

#network_tagsArray<String>

Network tags associated with this resource. Like labels, network tags are a type of annotations used to group Google Cloud resources. See Labelling Google Cloud resources for more information. Corresponds to the JSON property networkTags

Returns:

  • (Array<String>)


2210
2211
2212
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2210

def network_tags
  @network_tags
end

#projectString

The project that this resource belongs to, in the form of projects/ project_number`. Corresponds to the JSON propertyproject`

Returns:

  • (String)


2216
2217
2218
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2216

def project
  @project
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2223
2224
2225
2226
2227
2228
2229
2230
2231
2232
2233
# File 'lib/google/apis/cloudasset_v1p1beta1/classes.rb', line 2223

def update!(**args)
  @additional_attributes = args[:additional_attributes] if args.key?(:additional_attributes)
  @asset_type = args[:asset_type] if args.key?(:asset_type)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @network_tags = args[:network_tags] if args.key?(:network_tags)
  @project = args[:project] if args.key?(:project)
end